==> aws-android-sdk-cognito-2.1.5-sources.jar: com/amazonaws/services/cognitosync/model/transform/ListDatasetsResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitosync.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.cognitosync.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;

import com.fasterxml.jackson.core.JsonToken;
import static com.fasterxml.jackson.core.JsonToken.*;

/**
 * List Datasets Result JSON Unmarshaller
 */
public class ListDatasetsResultJsonUnmarshaller implements Unmarshaller<ListDatasetsResult, JsonUnmarshallerContext> {

    public ListDatasetsResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        ListDatasetsResult listDatasetsResult = new ListDatasetsResult();

        int originalDepth = context.getCurrentDepth();
        String currentParentElement = context.getCurrentParentElement();
        int targetDepth = originalDepth + 1;

        JsonToken token = context.currentToken;
        if (token == null) token = context.nextToken();
        if (token == VALUE_NULL) return null;

        while (true) {
            if (token == null) break;

            if (token == FIELD_NAME || token == START_OBJECT) {
                if (context.testExpression("Datasets", targetDepth)) {
                    context.nextToken();
                    listDatasetsResult.setDatasets(new ListUnmarshaller<Dataset>(DatasetJsonUnmarshaller.getInstance()).unmarshall(context));
                }
                if (context.testExpression("Count", targetDepth)) {
                    context.nextToken();
                    listDatasetsResult.setCount(IntegerJsonUnmarshaller.getInstance().unmarshall(context));
                }
                if (context.testExpression("NextToken", targetDepth)) {
                    context.nextToken();
                    listDatasetsResult.setNextToken(StringJsonUnmarshaller.getInstance().unmarshall(context));
                }
            } else if (token == END_ARRAY || token == END_OBJECT) {
                if (context.getLastParsedParentElement() == null || context.getLastParsedParentElement().equals(currentParentElement)) {
                    if (context.getCurrentDepth() <= originalDepth) break;
                }
            }

            token = context.nextToken();
        }
        
        return listDatasetsResult;
    }

    private static ListDatasetsResultJsonUnmarshaller instance;
    public static ListDatasetsResultJsonUnmarshaller getInstance() {
        if (instance == null) instance = new ListDatasetsResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-cognito-2.2.4-sources.jar: com/amazonaws/services/cognitosync/model/transform/ListDatasetsResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cognitosync.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import com.amazonaws.services.cognitosync.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * List Datasets Result JSON Unmarshaller
 */
public class ListDatasetsResultJsonUnmarshaller implements Unmarshaller<ListDatasetsResult, JsonUnmarshallerContext> {

    public ListDatasetsResult unmarshall(JsonUnmarshallerContext context) throws Exception {
        ListDatasetsResult listDatasetsResult = new ListDatasetsResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            
            if (name.equals("Datasets")) {
                listDatasetsResult.setDatasets(new ListUnmarshaller<Dataset>(DatasetJsonUnmarshaller.getInstance()).unmarshall(context));
            } else 
            if (name.equals("Count")) {
                listDatasetsResult.setCount(IntegerJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            if (name.equals("NextToken")) {
                listDatasetsResult.setNextToken(StringJsonUnmarshaller.getInstance().unmarshall(context));
            } else 
            {
                reader.skipValue();
            }
            
        }
        reader.endObject();
        
        return listDatasetsResult;
    }

    private static ListDatasetsResultJsonUnmarshaller instance;
    public static ListDatasetsResultJsonUnmarshaller getInstance() {
        if (instance == null) instance = new ListDatasetsResultJsonUnmarshaller();
        return instance;
    }
}
